# pyMEGA

**Warning: This repository is under heavy development and the content is not final yet.**

pyMEGA is a deep learning package for identifying cancer-associated tissue-resident microbes.

If you have any questions or feedback, please contact Qin Ma <qin.ma@osumc.edu>.

## dev environment

```{bash}
python: 3.7.12
pytorch: 1.4.0
torch-geometric: 2.0.1
NVIDIA Driver Version: 450.102.04
CUDA Version: 11.0
GPU: A100-PCIE-80GB
System: Red Hat Enterprise Linux release 8.3 (Ootpa)
```

## Preparations

### Example data

todo

### installation

- python: 3.7
- pytorch: 1.4.0
- cuda: 10.2
- torch_geometric: 1.4

```{bash}
conda create -n pyMEGA_env python=3.7
```

## Acknowledgements

Maintainer: [Cankun Wang](https://github.com/Wang-Cankun)

Contributors:

- [Cankun Wang](https://github.com/Wang-Cankun)